function [call, put, conf] = BS_MC(S,K,r,sigma,T,N)
    % K = strike price
    % S = asset spot price 
    % sigma = volatility
    % r = risk-free interest rate
    % T = time to maturity
    % N = number of simulations
    
    % We generate a standard Gaussian vectors
    Z = randn(N,1) ;
    
    % We generate final asset prices from the random vector
    S_fin = S * exp( (r-0.5*sigma^2)*T + sigma*sqrt(T)*Z ) ;
    
    % We compute the payoff vector for both call and put
    resC = max(S_fin - K, 0) ;
    resP = max(K - S_fin, 0) ;
    
    % We finally discount the average of the payoff
    call = exp(-r*T) * mean(resC) ;
    put = exp(-r*T) * mean(resP) ;
    
    % We compute the variance and the confidence intervall
    var = sum((resC-mean(resC).^2)/(N-1) ;
    conf = 1.96*var/sqrt(N) ;
end