function [call, put, conf] = antitheticBS_MC(S,K,r,sigma,T,N)
    % S = sport price
    % K = strike price
    % r = risk-free interest rate
    % sigma = volatility
    % T = time to maturity
    % N = number of simulations
    
    % We generate a standard Gaussian vector
    Z = randn(N,1) ;
    % We generate the antithetic random vector
    nZ = -Z ;
    
    % We generate final asset prices from both random vectors
    pS_fin = S * exp((r-0.5*sigma^2)*T + sigma*sqrt(T)*Z ) ;
    nS_fin = S * exp((r-0.5*sigma^2)*T + sigma*sqrt(T)*nZ ) ;
    
    % We compute the payoff vector for the call for both random vectors
    resCp = max(pS_fin - K, 0) ;
    resCn = max(nS_fin - K, 0) ;
    % We compute the payoff vector for the put for both random vectors
    resPp = max(K - pS_fin, 0) ;
    resPn = max(K - nS_fin, 0) ;
    
    % We compute the average between normal and antithetic payoffs
    resC = 0.5 * (resCp + resCn) ;
    resP = 0.5 * (resPp + resPn) ;
    
    % We finally discount the average of the payoff
    call = exp(-r*T)*mean(resC) ;
    put = exp(-r*T)*mean(resP) ;
    
    % We compute the variance and the confidence intervall
    var = sum((resC-mean(resC).^2)/(N-1) ;
    conf = 1.96*var/sqrt(N) ;
end