function [call,put] = controlBS_MC(S,K,r,sigma,T,N)
    % S = sport price
    % K = strike price
    % r = risk-free interest rate
    % sigma = volatility
    % T = time to maturity
    % N = number of simulations
    
    % We generate a standard Gaussian vector
    Z = randn(N,1) ;
    
    % We generate final asset prices from the random vector
    S_fin = S*exp((r-0.5*sigma^2)*T + sigma*sqrt(T)*Z) ;
    
    % We compute the payoff vector for both call and put
    resC = max(S_fin - K, 0) ;
    resP = max(K - S_fin, 0) ;
    
    % We substract the mean to each payoff
    newC = resC - mean(resC) ;
    newP = resP - mean(resP) ;
    % We substract the mean to each final price
    newS = S_fin - mean(S_fin) ;
    
    % We compute the value of beta for both call and put
    bC = mean(newC.*newS)/mean(newS.*newS) ;
    bP = mean(newP.*newS)/mean(newS.*newS) ;
    
    % We compute the payoff control variates
    finalC = resC - bC*(S_fin - exp(r*T)*S) ;
    finalP = resP - bP*(S_fin - exp(r*T)*S) ;
    
    % We finally discount the average of the payoff
    call = exp(-r*T) * mean(finalC) ;
    put = exp(-r*T) * mean(finalP) ;
end

