function [call, put, conf] = controlMC(K, S1, S2, sigma1, sigma2, mu1, mu2, rho, r, T, N)
    % K = strike price
    % S1 = spot price for asset 1
    % S2 = spot price for asset 2
    % sigma1 = volatility for asset 1
    % sigma2 = volatility for asset 2
    % mu1 = cost of carry for asset 1
    % mu2 = cost of carry for asset 2
    % rho = correlation between assets
    % r = risk-free rate
    % T = time to maturity
    % N = number of simulations
    
    S1_fin = zeros(N,1) ;
    S2_fin = zeros(N,1) ;
    strike = K * ones(N,1) ;
    for i=1:N
        U = randn ;
        V = randn ;
        S1_fin(i) = S1 * exp( (mu1-0.5*sigma1^2)*T + sigma1*rho*sqrt(T)*U + sigma2*sqrt(1-rho^2)*sqrt(T)*V ) ;
        S2_fin(i) = S2 * exp( (mu2-0.5*sigma2^2)*T + sigma2*sqrt(T)*U ) ;
    end
    resC = (S2_fin) - strike ;
    %resC = (S1_fin - S2_fin) - strike ;
    resC = max(resC,0) ;
    meanC = mean(resC) ;
    newC = resC - meanC ;
    
    %newS1 = S1_fin - mean(S1_fin) ;
    newS2 = S2_fin - mean(S2_fin) ;
    
    b1 = mean(newC.*newS2)/mean(newS2.*newS2) ;
    final = resC - b1*(S2_fin - exp(r*T)*S2) ;
    mm = mean(final) ;
    call = exp(-r*T)*mm ;
    
    
    put = 0 ;
    
    var = sum((final-mm).^2)/(N-1) ;
    conf = 1.96*var/sqrt(N) ;
    


end

